package com.vendor.burn.serial.workers;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.model.FlashType;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.event.EventType;
import com.vendor.burn.model.receive.ReceiveTimeOutException;
import com.vendor.burn.serial.workers.CallLibJTAGWorker;
import com.vendor.burn.serial.workers.CallLibUSBWorker;
import com.vendor.burn.serial.workers.PartitionBurnerWorker;
import com.vendor.burn.utilitily.FileUtils;
import com.vendor.platform.api.statistics.ToolStatistics;
import java.io.File;
import java.io.IOException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.SubMonitor;

public class DdrBurnerWorker extends PartitionBurnerWorker {
  public static final String commontStart = "usbtftp start";
  
  public static final String commontError = "usbtftp error";
  
  public static final String commontEnd = "usbtftp end";
  
  public static final int DOWNLOADCOMMANDLENGTH = 3;
  
  public static final int UPLOADCOMMANDLENGTH = 4;
  
  private static final int receivedNumber = 10;
  
  public DdrBurnerWorker(IBurner burner) {
    super(burner);
    this.burner = burner;
  }
  
  public boolean burn(IProgressMonitor uiMonitor, String directory) {
    ToolStatistics.INSTANCE.logUsage(Messages.FASTBOOT_MessageDialog_Title, "Ddr burn", "ChipName: " + this.burner
        .getBurnContext().getDeviceSetting().getName());
    ToolStatistics.INSTANCE.logToolInUse(Messages.FASTBOOT_MessageDialog_Title);
    String versionInfo = getVersionInfo("Ddr burn");
    CallLibJTAGWorker.printDebugInfo(versionInfo);
    monitor.getEvent().init(EventType.DDR_BURN);
    uiMonitor.beginTask("Ddr burn", 100);
    setProgressMonitor(uiMonitor);
    registerJnaFunction(this.uimonitor, 100);
    TransferWay curTransferWay = getBurner().getBurnContext().getTransferWay();
    if (curTransferWay == TransferWay.USBBootrom || curTransferWay == TransferWay.USBNonNude) {
      setFlashType(FlashType.ddr);
      while (true) {
        boolean startResult = waitOpenUsb(uiMonitor, curTransferWay);
        uiMonitor.worked(20);
        try {
          if (startResult) {
            if (uiMonitor.isCanceled()) {
              sendUsbCommand("usbtftp error");
              CallLibUSBWorker.closeUsb(curTransferWay);
              break;
            } 
            getCurReceived();
            if (!sendUsbCommand("usbtftp start")) {
              sendUsbCommand("usbtftp error");
              CallLibUSBWorker.closeUsb(curTransferWay);
              continue;
            } 
            uiMonitor.worked(30);
            String received = null;
            int number = 0;
            while (!uiMonitor.isCanceled()) {
              if (number == 10) {
                infoln("\nrequest information number:\t" + number);
                break;
              } 
              received = getCurUsbCommonReceived();
              if (received == null || received.length() <= 0) {
                infoln("\nrequest information is empty.\t");
                number++;
                continue;
              } 
              int index = received.indexOf("\n");
              if (index > 0)
                received = received.substring(0, index); 
              received = received.trim();
              infoln("\nrequest information:\t" + received);
              if (received.toLowerCase().startsWith("usbtftp ")) {
                String[] commons = received.split(" ");
                if (commons.length < 3) {
                  warning("\nSend command format error, refer to ' usbtftp get addr file '.");
                  sendUsbCommand("usbtftp error");
                  break;
                } 
                if (commons.length == 3) {
                  downloadFile(commons, directory, uiMonitor, curTransferWay);
                } else if (commons.length == 4) {
                  uploadFile(commons, directory, uiMonitor);
                } 
                if (!sendUsbCommand("usbtftp end")) {
                  sendUsbCommand("usbtftp error");
                  break;
                } 
                try {
                  Thread.sleep(300L);
                } catch (InterruptedException interruptedException) {}
                break;
              } 
              number++;
            } 
          } 
        } finally {
          CallLibUSBWorker.closeUsb(curTransferWay);
        } 
        if (uiMonitor.isCanceled())
          break; 
      } 
    } else {
      warningln("\n" + Messages.DdrComposite_OnlyUsb);
    } 
    return true;
  }
  
  private void uploadFile(String[] commons, String directory, IProgressMonitor uiMonitor) {
    String addressStr = commons[1];
    String fileName = commons[2];
    String lengthStr = commons[3];
    File file = new File(directory + directory + File.separator);
    if (file.exists())
      FileUtils.deleteFile(file); 
    uiMonitor.setTaskName("Uploading File : " + file.getName());
    uiMonitor.worked(50);
    SubMonitor subProgressMonitor = SubMonitor.convert(this.uimonitor, "", 100);
    this.uimonitor.setTaskName("Uploading " + file.getName());
    subProgressMonitor.setTaskName("Uploading File : " + file.getName());
    infoln("\nSend command:\tUploading File : " + file.getName());
    int ddrAddress = getAddress(addressStr);
    if (ddrAddress == -1) {
      warning("\nmemory address error :\t" + addressStr);
      sendUsbCommand("usbtftp error");
      return;
    } 
    int length = getAddress(lengthStr);
    if (length == 0) {
      warning("\nmemory address length error :\t" + length);
      sendUsbCommand("usbtftp error");
      return;
    } 
    boolean loadResult = CallLibUSBWorker.uploadFileByUsb(file, 0, 0, getBurner().getBurnContext()
        .getTransferWay());
    if (!loadResult) {
      returnError(Messages.ERROR_INFO_USB_UPLOAD_FAILED);
      sendUsbCommand("usbtftp error");
      return;
    } 
    uiMonitor.worked(80);
  }
  
  private void downloadFile(String[] commons, String directory, IProgressMonitor uiMonitor, TransferWay curTransferWay) {
    String addressStr = commons[1];
    String fileName = commons[2];
    File file = new File(directory + directory + File.separator);
    if (!file.exists()) {
      warning("\nFile does not exist:\t" + file.getPath());
      sendUsbCommand("usbtftp error");
      return;
    } 
    uiMonitor.setTaskName("Downloading File : " + file.getName());
    uiMonitor.worked(50);
    SubMonitor subProgressMonitor = SubMonitor.convert(this.uimonitor, "", 100);
    this.uimonitor.setTaskName("Burning " + file.getName());
    subProgressMonitor.setTaskName("Downloading File : " + file.getName());
    infoln("\nSend command:\tDownloading File : " + file.getName());
    int ddrAddress = getAddress(addressStr);
    if (ddrAddress == 0) {
      warning("\nDownload memory address Error :\t" + addressStr);
      sendUsbCommand("usbtftp error");
      return;
    } 
    boolean loadResult = CallLibUSBWorker.downloadFileByUsb(file, ddrAddress, curTransferWay);
    if (!loadResult) {
      returnError(Messages.ERROR_INFO_USB_DOWNLOAD_FAILED);
      sendUsbCommand("usbtftp error");
      return;
    } 
    uiMonitor.worked(80);
  }
  
  private int getAddress(String addressStr) {
    if (addressStr.toLowerCase().indexOf("0x") == 0)
      addressStr = addressStr.substring(2, addressStr.length()); 
    int index = addressStr.indexOf("\n");
    if (index > 0)
      addressStr = addressStr.substring(0, index); 
    try {
      return (int)Long.parseLong(addressStr, 16);
    } catch (NumberFormatException numberFormatException) {
      return -1;
    } 
  }
  
  private boolean sendUsbCommand(String infocmd) {
    try {
      if (!sendCommand(infocmd)) {
        returnError("Failed to send command " + infocmd + ". ");
        return false;
      } 
    } catch (IOException iOException) {
    
    } catch (ReceiveTimeOutException receiveTimeOutException) {}
    return true;
  }
}
